<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="27"/>
        <source>Jump to today</source>
        <translation>Перейти до поточної дати</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <source>Jump to</source>
        <translation>Перейти до</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="29"/>
        <source>New event</source>
        <translation>Створити подію</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="20"/>
        <source>Agenda</source>
        <translation>Порядок денний</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="27"/>
        <source>Time in advance</source>
        <translation>Час до події</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="37"/>
        <source>Hours</source>
        <translation>Година</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="57"/>
        <source>Minutes</source>
        <translation>Хвилина</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="77"/>
        <source>Seconds</source>
        <translation>Секунда</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="17"/>
        <source>Enable</source>
        <translation>Активне</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="13"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="24"/>
        <source>None</source>
        <translation>Жодного</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="35"/>
        <source>Exact</source>
        <translation>У момент початку</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="37"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>За %n годину</numerusform>
            <numerusform>За %n години</numerusform>
            <numerusform>За %n годин</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="38"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>За %n хвилину</numerusform>
            <numerusform>За %n хвилини</numerusform>
            <numerusform>За %n хвилин</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="39"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>За %n секунду</numerusform>
            <numerusform>За %n секунди</numerusform>
            <numerusform>За %n секунд</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="41"/>
        <source>%1:%2:%3 before</source>
        <translation>За %1:%2:%3</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>From beginning</source>
        <translation>З початку</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="38"/>
        <source>From end</source>
        <translation>З кінця</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="49"/>
        <source>By day of month</source>
        <translation>За днем місяця</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="51"/>
        <source>By week of year</source>
        <translation>За тижнем року</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="53"/>
        <source>By day of year</source>
        <translation>За днем року</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="21"/>
        <source>By month</source>
        <translation>За місяцем</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="20"/>
        <source>By day of week</source>
        <translation>За днем тижня</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="54"/>
        <source>From beginning</source>
        <translation>З початку</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="55"/>
        <source>From end</source>
        <translation>З кінця</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="6"/>
        <source>Edit calendar</source>
        <translation>Змінити календар</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="56"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="66"/>
        <source>Visible</source>
        <translation>Видимий</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="26"/>
        <source>Export</source>
        <translation>Експорт</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="27"/>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="128"/>
        <source>Save file</source>
        <translation>Зберегти до файлу</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="141"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Видалити цей календар з його подіями, завданнями та нотатками?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Календар</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Змінити календарі</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="25"/>
        <source>New</source>
        <translation>Новий</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n видимий</numerusform>
            <numerusform>%n видимих</numerusform>
            <numerusform>%n видимих</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Весь
день</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Edit</source>
        <translation>Редагувати</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="181"/>
        <source>Edit</source>
        <translation>Редагувати</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="182"/>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="181"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Тиждень %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Виберіть дату</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Введіть номер дня</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Попередній день</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Наступний день</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Перейти до поточної дати</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Перейти до</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n подія</numerusform>
            <numerusform>%n події</numerusform>
            <numerusform>%n подій</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n завдання</numerusform>
            <numerusform>%n завдання</numerusform>
            <numerusform>%n завдань</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n нотатка</numerusform>
            <numerusform>%n нотатки</numerusform>
            <numerusform>%n нотаток</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Де</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Весь день</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>До</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Repeat</source>
        <translation>Повторювати</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="128"/>
        <source>Calendar</source>
        <translation>Календар</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Alarm</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="145"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="29"/>
        <source>Edit event</source>
        <translation>Змінити подію</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="32"/>
        <source>New event</source>
        <translation>Нова подія</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Подія</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>До</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Повторюється</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="179"/>
        <source>Previous event</source>
        <translation>Попередня подія</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="184"/>
        <source>Next event</source>
        <translation>Наступна подія</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="189"/>
        <source>Edit event</source>
        <translation>Змінити подію</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="194"/>
        <source>Delete event</source>
        <translation>Видалити подію</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="199"/>
        <source>Clone event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="204"/>
        <source>Automatic links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="145"/>
        <source>From</source>
        <translation>Від</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="145"/>
        <source>On</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="215"/>
        <location filename="../EventWindow.cpp" line="236"/>
        <source>No more events</source>
        <translation>Більше немає подій</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="22"/>
        <source>Calendar</source>
        <translation>Календар</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>Edit note</source>
        <translation>Змінити нотатку</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="32"/>
        <source>New note</source>
        <translation>Нова нотатка</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="27"/>
        <source>New note</source>
        <translation>Нова нотатка</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="46"/>
        <source>Notes</source>
        <translation>Нотатки</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="119"/>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="120"/>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="56"/>
        <source>Month</source>
        <translation>Місяць</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="57"/>
        <source>Week</source>
        <translation>Тиждень</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="58"/>
        <source>Agenda</source>
        <translation>Порядок денний</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="59"/>
        <source>Tasks</source>
        <translation>Завдання</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="60"/>
        <source>Notes</source>
        <translation>Нотатки</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="61"/>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Previous month</source>
        <translation>Попередній місяць</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>Next month</source>
        <translation>Наступний місяць</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="65"/>
        <source>Jump to today</source>
        <translation>Перейти до поточної дати</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="66"/>
        <source>Jump to</source>
        <translation>Перейти до</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="67"/>
        <source>New event</source>
        <translation>Нова подія</translation>
    </message>
</context>
<context>
    <name>NewComponentWidget</name>
    <message>
        <location filename="../NewComponentWidget.h" line="24"/>
        <source>New event</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ChangeManager.cpp" line="120"/>
        <location filename="../ChangeManager.cpp" line="143"/>
        <source>Unable to edit birthdays</source>
        <translation>Редагування днів народжень недоступне</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="158"/>
        <source>Delete component?</source>
        <translation>Видалити компонент?</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Повторення</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="30"/>
        <source>Repeat</source>
        <translation>Повторювати</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="40"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="61"/>
        <source>Frequency</source>
        <translation>Частота</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="72"/>
        <source>Daily</source>
        <translation>Щоденно</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="77"/>
        <source>Weekly</source>
        <translation>Щотижня</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="82"/>
        <source>Monthly</source>
        <translation>Щомісяця</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="87"/>
        <source>Yearly</source>
        <translation>Щороку</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="95"/>
        <source>Interval</source>
        <translation>Інтервал</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="119"/>
        <source>Forever</source>
        <translation>Завжди</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="124"/>
        <source>Until</source>
        <translation>До певної дати</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="129"/>
        <source>Count</source>
        <translation>Певну кількість разів</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="35"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="37"/>
        <source>Never</source>
        <translation>Ніколи</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="39"/>
        <source>External</source>
        <translation>Зовнішній</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="41"/>
        <source>Every day</source>
        <translation>Щодня</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="43"/>
        <source>Every workday</source>
        <translation>У робочі дні</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="45"/>
        <source>Every week</source>
        <translation>Щотижня</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="47"/>
        <source>Every month</source>
        <translation>Щомісяця</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="49"/>
        <source>Every year</source>
        <translation>Щороку</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="51"/>
        <source>Complex</source>
        <translation>Складне правило</translation>
    </message>
</context>
<context>
    <name>RulePickDialog</name>
    <message>
        <location filename="../recurrence/RulePickDialog.ui" line="6"/>
        <source>Select rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="16"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="17"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>RulePickSelector</name>
    <message>
        <location filename="../recurrence/RulePickSelector.cpp" line="14"/>
        <source>Rule %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="32"/>
        <source>Edit calendars</source>
        <translation>Редагувати календарі</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="42"/>
        <source>Alarm tone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="52"/>
        <source>Delete events</source>
        <translation>Видаляти події</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="62"/>
        <source>Delete tasks</source>
        <translation>Видаляти завдання</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="16"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="46"/>
        <source>Never</source>
        <translation>Ніколи</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="48"/>
        <location filename="../settings/SettingsDialog.cpp" line="50"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Старші за %n тиждень</numerusform>
            <numerusform>Старші за %n тижні</numerusform>
            <numerusform>Старші за %n тижнів</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="52"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Старші за %n місяць</numerusform>
            <numerusform>Старші за %n місяці</numerusform>
            <numerusform>Старші за %n місяців</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="54"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Старші за %n рік</numerusform>
            <numerusform>Старші за %n роки</numerusform>
            <numerusform>Старші за %n років</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Calendar</source>
        <translation>Календар</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <location filename="../TodoEditDialog.ui" line="61"/>
        <source>Alarm</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="92"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="27"/>
        <source>Edit task</source>
        <translation>Змінити завдання</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="30"/>
        <source>New task</source>
        <translation>Нове завдання</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Завдання</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Призначене на</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Сповіщення</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="169"/>
        <source>Edit task</source>
        <translation>Змінити завдання</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="174"/>
        <source>Delete task</source>
        <translation>Видалити завдання</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="179"/>
        <source>Clone task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="184"/>
        <source>Automatic links</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="33"/>
        <source>New task</source>
        <translation>Нове завдання</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="40"/>
        <source>Hide completed</source>
        <translation>Приховати виконані</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Delete completed</source>
        <translation>Видалити виконані</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="78"/>
        <source>Tasks</source>
        <translation>Завдання</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="197"/>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="198"/>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="223"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Видалити завершені завдання з усіх календарів?</translation>
    </message>
</context>
<context>
    <name>TunePickDialog</name>
    <message>
        <location filename="../settings/TunePickDialog.ui" line="6"/>
        <source>Choose alarm tone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="17"/>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="67"/>
        <source>Add alarm tone</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="31"/>
        <source>w%1</source>
        <translation>т%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="42"/>
        <source>Previous week</source>
        <translation>Попередній тиждень</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Next week</source>
        <translation>Наступний тиждень</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Jump to today</source>
        <translation>Перейти до поточної дати</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to</source>
        <translation>Перейти до</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>New event</source>
        <translation>Нова подія</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="69"/>
        <source>Week %1 (%2)</source>
        <translation>Тиждень %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="363"/>
        <source>All day</source>
        <translation>Весь день</translation>
    </message>
</context>
</TS>
